@@ -1,21 +1,8 @@
 /*
- *   Copyright (C) 2007-2009 Petri Damstén <damu@iki.fi>
- *   Copyright (C) 2014 John Layt <jlayt@kde.org>
+ *   SPDX-FileCopyrightText: 2007-2009 Petri Damstén <damu@iki.fi>
+ *   SPDX-FileCopyrightText: 2014 John Layt <jlayt@kde.org>
  *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *   SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef KUNITCONVERSION_UNITCATEGORY_P_H
@@ -25,7 +12,7 @@
 
 #include <KI18n/KLocalizedString>
 
-#include <QtCore/QMap>
+#include <QMap>
 
 namespace KUnitConversion
 {
